pub struct Register16 { /* private fields */ }
Fast 16-bit register which, as opposed to the other Register16, it does not carries out the simulation with other building blocks, but it emulates it with native code.

Implementations

Carries out the simulation, taking as input:

  • inp: data bit
  • load: whether to write inp into the register

And, at time t, returns (out) the following:

if load(t-1) { inp(t-1) }
else { out(t-1) }