Struct acs::mem::fast::register16::Register16
source · [−]pub struct Register16 { /* private fields */ }Expand description
Fast 16-bit register which, as opposed to the other Register16,
it does not carries out the simulation with other building blocks,
but it emulates it with native code.
Implementations
sourceimpl Register16
impl Register16
sourcepub fn sim(&mut self, inp: Signal16, load: Signal) -> Signal16
pub fn sim(&mut self, inp: Signal16, load: Signal) -> Signal16
Carries out the simulation, taking as input:
inp: data bitload: whether to writeinpinto the register
And, at time t, returns (out) the following:
if load(t-1) { inp(t-1) }
else { out(t-1) }pub fn tock(&mut self) -> Signal16
pub fn out(&self) -> Signal16